/***************************************************************************
                          raction.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

#ifndef RACTION_H
#define RACTION_H

#include <qobject.h>

#include "ractiondef.h"
#include "reventdef.h"
#include "rdimdlg.h"

class QMouseEvent;
class QKeyEvent;
class RGraphic;
class RInputPanel;
class RSnap;
class RStatusPanel;
class RDimDlg;


class RAction : public QObject
{
  Q_OBJECT
public:

  RAction();
  ~RAction();

  RGraphic* currentDoc();
  RGraphic* currentOut();
  RSnap* snapper();
  RStatusPanel* statusPanel();
  RInputPanel* inputPanel();
  RDimDlg* dimensionDlg();

};


#endif

// EOF

